==> smartgwt-4.1p.zip: com/smartgwt/client/widgets/drawing/AnimateShowEffect.java <==
/*
 * Smart GWT (GWT for SmartClient)
 * Copyright 2008 and beyond, Isomorphic Software, Inc.
 *
 * Smart GWT is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version 3
 * as published by the Free Software Foundation.  Smart GWT is also
 * available under typical commercial license terms - see
 * http://smartclient.com/license
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 */
/* sgwtgen */
 
package com.smartgwt.client.widgets.drawing;


import com.smartgwt.client.event.*;
import com.smartgwt.client.core.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.events.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.callbacks.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.bean.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.events.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.tile.events.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.grid.events.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.layout.events.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.rte.*;
import com.smartgwt.client.widgets.rte.events.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.tree.events.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.calendar.events.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.google.gwt.user.client.ui.Widget;
import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.user.client.Element;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.google.gwt.event.shared.*;
import com.google.gwt.event.shared.HasHandlers;

/**
 * Configuration object for effect to apply during an animated show or hide.
 */
@BeanFactory.FrameworkClass
public class AnimateShowEffect extends DataClass {

    public static AnimateShowEffect getOrCreateRef(JavaScriptObject jsObj) {
        if(jsObj == null) return null;
        return new AnimateShowEffect(jsObj);
    }


    public AnimateShowEffect(){
        
    }

    public AnimateShowEffect(JavaScriptObject jsObj){
        
        setJavaScriptObject(jsObj);
    }


    // ********************* Properties / Attributes ***********************

    /**
     * Effect to apply
     *
     * @param effect  Default value is null
     */
    public void setEffect(AnimationEffect effect) {
        setAttribute("effect", effect == null ? null : effect.getValue());
    }

    /**
     * Effect to apply
     *
     * @return AnimationEffect
     */
    public AnimationEffect getEffect()  {
        return EnumUtil.getEnum(AnimationEffect.values(), getAttribute("effect"));
    }

    /**
     * For hide animations of type <code>"wipe</code> and    <code>"slide"</code> this attribute specifies where the wipe /
     * slide should finish.   Valid options are <code>"T"</code> (vertical animation upwards to the top of the canvas,   the
     * default behavior) and <code>"L"</code> (horizontal animation to the left of the   canvas).
     *
     * @param endsAt  Default value is null
     */
    public void setEndsAt(String endsAt) {
        setAttribute("endsAt", endsAt);
    }

    /**
     * For hide animations of type <code>"wipe</code> and    <code>"slide"</code> this attribute specifies where the wipe /
     * slide should finish.   Valid options are <code>"T"</code> (vertical animation upwards to the top of the canvas,   the
     * default behavior) and <code>"L"</code> (horizontal animation to the left of the   canvas).
     *
     * @return String
     */
    public String getEndsAt()  {
        return getAttributeAsString("endsAt");
    }

    /**
     * For show animations of type <code>"wipe"</code> and   <code>"slide"</code> this attribute specifies where the wipe /
     * slide should originate.   Valid values are <code>"T"</code> (vertical animation from the top down, the    default
     * behavior), and <code>"L"</code> (horizontal animation from the left side).
     *
     * @param startFrom  Default value is null
     */
    public void setStartFrom(String startFrom) {
        setAttribute("startFrom", startFrom);
    }

    /**
     * For show animations of type <code>"wipe"</code> and   <code>"slide"</code> this attribute specifies where the wipe /
     * slide should originate.   Valid values are <code>"T"</code> (vertical animation from the top down, the    default
     * behavior), and <code>"L"</code> (horizontal animation from the left side).
     *
     * @return String
     */
    public String getStartFrom()  {
        return getAttributeAsString("startFrom");
    }

    // ********************* Methods ***********************

    // ********************* Static Methods ***********************

    // ***********************************************************

}

==> smartgwt-5.1p.zip: com/smartgwt/client/widgets/drawing/AnimateShowEffect.java <==
/*
 * Smart GWT (GWT for SmartClient)
 * Copyright 2008 and beyond, Isomorphic Software, Inc.
 *
 * Smart GWT is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version 3
 * as published by the Free Software Foundation.  Smart GWT is also
 * available under typical commercial license terms - see
 * http://smartclient.com/license
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 */
/* sgwtgen */
 
package com.smartgwt.client.widgets.drawing;


import com.smartgwt.client.event.*;
import com.smartgwt.client.core.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.events.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.callbacks.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.bean.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.events.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.tile.events.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.grid.events.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.layout.events.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.rte.*;
import com.smartgwt.client.widgets.rte.events.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.tree.events.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.calendar.events.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;

import com.google.gwt.user.client.ui.Widget;
import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.user.client.Element;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.google.gwt.event.shared.*;
import com.google.gwt.event.shared.HasHandlers;

/**
 * Configuration object for effect to apply during an animated show or hide.
 */
@BeanFactory.FrameworkClass
public class AnimateShowEffect extends DataClass {

    public static AnimateShowEffect getOrCreateRef(JavaScriptObject jsObj) {
        if(jsObj == null) return null;
        return new AnimateShowEffect(jsObj);
    }


    public AnimateShowEffect(){
        
    }

    public AnimateShowEffect(JavaScriptObject jsObj){
        
        setJavaScriptObject(jsObj);
    }


    // ********************* Properties / Attributes ***********************

    /**
     * Effect to apply
     *
     * @param effect  Default value is null
     */
    public void setEffect(AnimationEffect effect) {
        if (readOnly) {
            ConfigUtil.warnOfPostConfigModification(AnimateShowEffect.class, "setEffect", "AnimationEffect");
        }
        setAttribute("effect", effect == null ? null : effect.getValue());
    }

    /**
     * Effect to apply
     *
     * @return AnimationEffect
     */
    public AnimationEffect getEffect()  {
        return EnumUtil.getEnum(AnimationEffect.values(), getAttribute("effect"));
    }
    

    /**
     * For hide animations of type <code>"wipe</code> and    <code>"slide"</code> this attribute specifies where the wipe /
     * slide should finish.   Valid options are <code>"T"</code> (vertical animation upwards to the top of the canvas,   the
     * default behavior) and <code>"L"</code> (horizontal animation to the left of the   canvas).
     *
     * @param endsAt  Default value is null
     */
    public void setEndsAt(String endsAt) {
        if (readOnly) {
            ConfigUtil.warnOfPostConfigModification(AnimateShowEffect.class, "setEndsAt", "String");
        }
        setAttribute("endsAt", endsAt);
    }

    /**
     * For hide animations of type <code>"wipe</code> and    <code>"slide"</code> this attribute specifies where the wipe /
     * slide should finish.   Valid options are <code>"T"</code> (vertical animation upwards to the top of the canvas,   the
     * default behavior) and <code>"L"</code> (horizontal animation to the left of the   canvas).
     *
     * @return String
     */
    public String getEndsAt()  {
        return getAttributeAsString("endsAt");
    }
    

    /**
     * For show animations of type <code>"wipe"</code> and   <code>"slide"</code> this attribute specifies where the wipe /
     * slide should originate.   Valid values are <code>"T"</code> (vertical animation from the top down, the    default
     * behavior), and <code>"L"</code> (horizontal animation from the left side).
     *
     * @param startFrom  Default value is null
     */
    public void setStartFrom(String startFrom) {
        if (readOnly) {
            ConfigUtil.warnOfPostConfigModification(AnimateShowEffect.class, "setStartFrom", "String");
        }
        setAttribute("startFrom", startFrom);
    }

    /**
     * For show animations of type <code>"wipe"</code> and   <code>"slide"</code> this attribute specifies where the wipe /
     * slide should originate.   Valid values are <code>"T"</code> (vertical animation from the top down, the    default
     * behavior), and <code>"L"</code> (horizontal animation from the left side).
     *
     * @return String
     */
    public String getStartFrom()  {
        return getAttributeAsString("startFrom");
    }
    

    // ********************* Methods ***********************

    // ********************* Static Methods ***********************

    // ***********************************************************

}
